==> smb4k_0.5.2.orig.tar.gz: smb4k-0.5.2/utilities/smb4k_kill.cpp <==
/***************************************************************************
    smb4k_kill  -  This is the kill utility for Smb4K.
                             -------------------
    begin                : So Sep 26 2004
    copyright            : (C) 2004 by Alexander Reinholdt
    email                : dustpuppy@mail.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif 

#include <iostream>
#include <fstream>
#include <cstring>
#include <cerrno>
#include <unistd.h>
using namespace std; 


//
// Returns the information about the program
//

void info()
{
  cout << "This is smb4k_kill, the kill utility for Smb4K." << endl;
  cout << "(c) 2004, Alexander Reinholdt" << endl << endl;
  cout << "Usage:" << endl;
  cout << " smb4k_kill <options>" << endl;
  cout << " smb4k_kill --help" << endl << endl;
  cout << "Arguments:" << endl;
  cout << "  --help\tDisplays this help screen and exits." << endl;
  cout << "  <options>\tThese are the options that you have to pass to kill." << endl;
}

//
// Finds the kill program
//

const char *findprog( const char *name )
{
  const char *paths[4] = { "/bin/", "/sbin/", "/usr/bin/", "/usr/sbin/" };
  string file = "";
  
  for ( int i = 0; i < 4; i++ )
  {
    string path( paths[i] );
    path.append( name );
      
    if ( access( path.c_str(), X_OK ) == 0 )
    {
      file.assign( path );
      break;
    }
  }

  if ( !strcmp( file.c_str(), "" ) )
  {
    cerr << "smb4k_kill: Could not find " << name << "." << endl;
    exit( EXIT_FAILURE );
  }
    
  return file.c_str();
}

//
// The main function
//

int main( int argc, char *argv[], char *envp[] )
{
  if ( argc < 2 )
  {
    info();
    exit( EXIT_FAILURE );
  }
  
  char *args[25];
  int k = 0;
  
  char *p = (char *)malloc( 100*sizeof(char) );
  
  args[k] = strcpy( p, findprog( "kill" ) );
  k++;
  
  for ( int i = 1; i < argc; i++ )
  {
    if ( !strcmp( argv[i], "--help" ) )
    {
      info();
      exit( EXIT_SUCCESS );
    }
    else
    {    
      char *t = (char *)malloc( 100*sizeof(char) );
      
      if ( !t )
      {
        cerr << "smb4k_kill: Out of memory" << endl;
        exit( EXIT_FAILURE );
      }
      
      if ( strlen( argv[i] ) > 100 )
      {
        cerr << "smb4k_kill: One or more arguments exceed 100 characters." << endl;
        exit( EXIT_FAILURE );
      }
                  
      args[k] = strcpy( t, argv[i] );
      k++;
      
      continue;    
    }
  }
  
  args[k] = NULL;
  
  if ( execve( args[0], args, envp ) == -1 )
  {
    int err_code = errno;
    
    cerr << "smb4k_kill: " << strerror( err_code ) << endl;
    exit( EXIT_FAILURE );
  }
  
  return EXIT_SUCCESS;
}

==> smb4k_0.6.5.orig.tar.gz: smb4k-0.6.5/utilities/smb4k_kill.cpp <==
/***************************************************************************
    smb4k_kill  -  This is the kill utility for Smb4K.
                             -------------------
    begin                : So Sep 26 2004
    copyright            : (C) 2004 by Alexander Reinholdt
    email                : dustpuppy@mail.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif 

#include <iostream>
#include <fstream>
#include <cstring>
#include <cerrno>
#include <unistd.h>
using namespace std; 


//
// Returns the information about the program
//

void info()
{
  cout << "This is smb4k_kill, the kill utility for Smb4K." << endl;
  cout << "(c) 2004-2005, Alexander Reinholdt" << endl << endl;
  cout << "Usage:" << endl;
  cout << " smb4k_kill <options>" << endl;
  cout << " smb4k_kill --help" << endl << endl;
  cout << "Arguments:" << endl;
  cout << "  --help\tDisplays this help screen and exits." << endl;
  cout << "  <options>\tThese are the options that you have to pass to kill." << endl;
  cout << endl;
}

//
// Finds the kill program
//

const char *findprog( const char *name )
{
  const char *paths[] = { "/bin/", "/sbin/", "/usr/bin/", "/usr/sbin/", "/usr/local/bin/", "/usr/local/sbin/" };
  string file = "";
  
  for ( uint i = 0; i < sizeof( paths ) / sizeof( char * ); i++ )
  {
    string path( paths[i] );
    path.append( name );
      
    if ( access( path.c_str(), X_OK ) == 0 )
    {
      file.assign( path );
      break;
    }
  }

  if ( !strcmp( file.c_str(), "" ) )
  {
    cerr << "smb4k_kill: Could not find " << name << "." << endl;
    exit( EXIT_FAILURE );
  }
    
  return file.c_str();
}

//
// The main function
//

int main( int argc, char *argv[], char *envp[] )
{
  if ( argc < 2 )
  {
    info();
    exit( EXIT_FAILURE );
  }
  
  char *args[25];
  int k = 0;
  
  char *p = (char *)malloc( 100*sizeof(char) );
  
  args[k] = strcpy( p, findprog( "kill" ) );
  k++;
  
  for ( int i = 1; i < argc; i++ )
  {
    if ( !strcmp( argv[i], "--help" ) )
    {
      info();
      exit( EXIT_SUCCESS );
    }
    else
    {    
      char *t = (char *)malloc( 100*sizeof(char) );
      
      if ( !t )
      {
        cerr << "smb4k_kill: Out of memory" << endl;
        exit( EXIT_FAILURE );
      }
      
      if ( strlen( argv[i] ) > 100 )
      {
        cerr << "smb4k_kill: One or more arguments exceed 100 characters." << endl;
        exit( EXIT_FAILURE );
      }
                  
      args[k] = strcpy( t, argv[i] );
      k++;
      
      continue;    
    }
  }
  
  args[k] = NULL;
  
  if ( execve( args[0], args, envp ) == -1 )
  {
    int err_code = errno;
    
    cerr << "smb4k_kill: " << strerror( err_code ) << endl;
    exit( EXIT_FAILURE );
  }
  
  return EXIT_SUCCESS;
}
